@@ -16,10 +16,14 @@ shinyServer(function(input, output) {
     "attribute"
   })
   
-  source("./src/radar/radar_server.R", local = TRUE, encoding = "UTF-8")
+  data('data_stock1')
+  data('data_gdp')
+  
   source("./src/pie/pie_server.R", local = TRUE, encoding = "UTF-8")
+  source("./src/radar/radar_server.R", local = TRUE, encoding = "UTF-8")
   source("./src/serial/serial_server.R", local = TRUE, encoding = "UTF-8")
   source("./src/xy/xy_server.R", local = TRUE, encoding = "UTF-8")
+  source("./src/stock/stock_server.R", local = TRUE, encoding = "UTF-8")
   source("./src/gauge/gauge_server.R", local = TRUE, encoding = "UTF-8")
   source("./src/funnel/funnel_server.R", local = TRUE, encoding = "UTF-8")
   source("./src/drilldown/drilldown_server.R", local = TRUE, encoding = "UTF-8")
