@@ -4,7 +4,7 @@ shiny::tabPanel(
     column(
       width = 12,
       rAmCharts::amChartsOutput("drillColumnChart1", type = "drill"),
-      rAmCharts::amChartsOutput("drillColumnChart2", type = "drill")
+      verbatimTextOutput("drillColumnChart1_code")
     )
   )
 )
\ No newline at end of file
